// domains.sieve
// This sieve filters out domains under the SUNET umbrella.
// Results are passed on to phishing.sieve and squatters.sieve

// https://regex101.com/ is a good place to test out regexes

if :notexists source.fqdn {
   drop // Abort processing if we cannot match against it.
}

// See if domain is anywhere in FQDN.
// Only match when domain is first or between to periods "."
// With chalmers as example:
// Matches:
//   chalmers.foo.com
//   foo.chalmers.com
//   foo.chalmers.bar.com
// No match:
//   chalmerss.com
//   www_chalmers.com
// Matching is split in two expressions to avoid expensive regexes.
// First see if domain is first in FQDN
// Then see if it it anywhere between two periods ".<domain>."
if (source.fqdn =~ '^(arkdes|bornet|bth|chalmers|csbnet|dnlab|du|efs|ehs|esss|fhs|gih|gsix|gu|hb|hh|hhs|hig|his|hkr|hv|irf|johannelund|ju|junet|kau|kb|ki|kkh|kks|kmh|konstfack|konstnarsnamnden|kth|kulturradet|kva|lansstyrelsen|liu|lnu|ltu|lu|maritima|mau|mdfnet|mdh|miun|mittag-leffler|modernamuseet|musikverket|nationalmuseum|ndgf|nordgen|nordiskamuseet|nordu|nrm|oru|polar|raa|riksarkivet|riksdagen|riksutstallningar|rj|rkh|sfhm|sh|shm|sics|sipri|skansen|sll|slu|smhi|sophiahemmet|sp|studentnatet|stupi|su|sunet|svenskaakademien|tekniskamuseet|tillvaxtverket|uhr|uka|umu|uniarts|unimaster|ur|uu|val|varldskulturmuseerna|vinnova|vr)\..*$')
 ||
   (source.fqdn =~ '\.(arkdes|bornet|bth|chalmers|csbnet|dnlab|du|efs|ehs|esss|fhs|gih|gsix|gu|hb|hh|hhs|hig|his|hkr|hv|irf|johannelund|ju|junet|kau|kb|ki|kkh|kks|kmh|konstfack|konstnarsnamnden|kth|kulturradet|kva|lansstyrelsen|liu|lnu|ltu|lu|maritima|mau|mdfnet|mdh|miun|mittag-leffler|modernamuseet|musikverket|nationalmuseum|ndgf|nordgen|nordiskamuseet|nordu|nrm|oru|polar|raa|riksarkivet|riksdagen|riksutstallningar|rj|rkh|sfhm|sh|shm|sics|sipri|skansen|sll|slu|smhi|sophiahemmet|sp|studentnatet|stupi|su|sunet|svenskaakademien|tekniskamuseet|tillvaxtverket|uhr|uka|umu|uniarts|unimaster|ur|uu|val|varldskulturmuseerna|vinnova|vr)\..*$') {
   keep // pass everything that could be interesting on to the next sieve
} else {
   drop // drop everything that's not remotely interesting
}
