// squatters.sieve
// This sieve runs after domains.sieve and aims to catch domain squatting.

// False positives are plentiful. Especially for "short" domains.
// We don't even care about domains with only two letters like uu.se, these will
// have way too many false positives.

// https://regex101.com/ is a good place to test out regexes

if :notexists source.fqdn {
   drop // Abort processing if we cannot match against it.
}

// Rule for dropping real domain certicates.
if source.fqdn =~ '\.(arkdes|bornet|bth|chalmers|csbnet|dnlab|du|efs|ehs|esss|fhs|gih|gsix|gu|hb|hh|hhs|hig|his|hkr|hv|irf|ju|junet|kau|kb|ki|kkh|kks|kmh|konstfack|konstnarsnamnden|kth|kth|kulturradet|kva|lansstyrelsen|liu|lnu|ltu|lu|maritima|mau|mdfnet|mdh|mdh|miun|mittag-leffler|modernamuseet|musikverket|nationalmuseum|nordiskamuseet|nrm|oru|polar|raa|riksarkivet|riksdagen|riksutstallningar|rj|rkh|sfhm|sh|shm|sics|skansen|sll|slu|smhi|sophiahemmet|sp|studentnatet|stupi|su|su|sunet|svenskaakademien|tekniskamuseet|tillvaxtverket|uhr|uka|umu|uniarts|unimaster|ur|uu|val|varldskulturmuseerna|vinnova|vr)\.se$' || source.fqdn =~ '\.(ndgf|nordgen|sipri)\.org$' || source.fqdn =~ '\.(nordu\.net|johannelund\.nu)$' {
   drop // drop real domains
} else {
   //add source.abuse_contact = 'cert-report@cert.sunet.se,fors@cert.sunet.se'
   add source.abuse_contact = 'cert-report@cert.sunet.se'
}

// Drop stuff used by cloud security
if source.fqdn =~ '.*\.m*cas(-gov.us|\.ms)$' {
   drop //
} elif source.fqdn =~ '.*\.admin-mcas.ms$' {
   drop
}

// CN has one of our domain names (.se) embedded. Suspected phishing
if source.fqdn =~ '\.(arkdes|bornet|bth|chalmers|csbnet|dnlab|du|efs|ehs|esss|fhs|gih|gsix|gu|hb|hh|hhs|hig|his|hkr|hv|irf|ju|junet|kau|kb|ki|kkh|kks|kmh|konstfack|konstnarsnamnden|kth|kth|kulturradet|kva|lansstyrelsen|liu|lnu|ltu|lu|maritima|mau|mdfnet|mdh|mdh|miun|mittag-leffler|modernamuseet|musikverket|nationalmuseum|nordiskamuseet|nrm|oru|polar|raa|riksarkivet|riksdagen|riksutstallningar|rj|rkh|sfhm|sh|shm|sics|skansen|sll|slu|smhi|sophiahemmet|sp|studentnatet|stupi|su|su|sunet|svenskaakademien|tekniskamuseet|tillvaxtverket|uhr|uka|umu|uniarts|unimaster|ur|uu|val|varldskulturmuseerna|vinnova|vr)\.se\..*$' {
   add comment = 'Probable phishing'
   drop // Hanterar i parallel sieve-expert
}

// CN has one of our domain names (.org) embedded. Suspected phishing
if source.fqdn =~ '\.(ndgf|nordgen|sipri)\.org\..*$' {
   add comment = 'Probable phishing domain cert registered'
   drop // Hanterar i produktion
}

// CN has one of our domain names (.net, .nu) embedded. Suspected phishing
if source.fqdn =~ '\.(nordu\.net|johannelund\.nu)\..*$' {
   add comment = 'Probable phishing'
   drop // Hanterar i produktion
}

// Keep only thos domains that contains more than three letters.
// These are dropped (bth|du|efs|ehs|fhs|gih|gu|hb|hh|hhs|hig|his|hkr|hv|irf|ju|kau|kb|ki|kkh|kks|kmh|kth|kva|liu|lnu|ltu|lu|mau|mdh|nrm|oru|raa|rj|rkh|sh|shm|sll|slu|sp|su|uhr|uka|umu|ur|uu|val|vr)

if source.fqdn !~ '.*\.(arkdes|bornet|chalmers|csbnet|dnlab|esss|gsix|johannelund|junet|konstfack|konstnarsnamnden|kulturradet|lansstyrelsen|maritima|mdfnet|miun|mittag-leffler|modernamuseet|musikverket|nationalmuseum|ndgf|nordgen|nordiskamuseet|nordu|polar|riksarkivet|riksdagen|riksutstallningar|sfhm|sics|sipri|skansen|smhi|sophiahemmet|studentnatet|stupi|sunet|svenskaakademien|tekniskamuseet|tillvaxtverket|uniarts|unimaster|varldskulturmuseerna|vinnova)\..*$' {
   drop // drop everything that's not remotely interesting
} else {
   add comment = 'Possible squatting domain cert registered'
}

// Chalmers chalmers.se
if source.fqdn =~ '^(.*\.)*chalmers\.(it)$' {
  drop
  // chalmers.it -> Chalmers IT-studenter
}

// Nordunet nordu.net
if source.fqdn =~ '^(.*\.)*nordu\.(no)$' {
   drop
   // nordu.no -> Nord Universitet, Universitetet i Nordland. (nord.no)
}

// Polarforskningssekretariatet polar.se
if source.fqdn =~ '^(.*\.)*polar\.(aero|co\.at|codes|com|com\.es|in|it|link|me|nu|one|vercel\.app)$' {
   drop
   // polar.aero -> JSC Polar Airlines, ryssland. Ingen www på polar.aero eller www.polar.aero
   // polar.co.at -> POLAR Entfeuchtung & Sanierung GmbH. Österikiskt saneringsföretag
   // polar.codes -> Till salu hos dan.com. Senast kollad 2020-12-10
   // polar.com -> Finska Polar Electro. Tillverkar pulsklockor o.dyl.
   // polar.com.es -> Till salu via Sedo Domain parking. Senast kollad 2020-12-10
   // polar.in -> Parkerad hos Sedo Domain Parking. Senast kollad 2020-12-10
   // polar.it -> Polar Sunglasses
   // polar.link -> Parkerad hos Sedo Domain Parking. Senast kollad 2020-12-10
   // polar.me -> Polar. Kanadensiskt företag inom marketing/advertising.
   // polar.nu -> Polar bemanning AB i Nässjö
   // polar.one -> Till salu hos dan.com. Senast kollad 2020-12-10
   // polar.vercel.app -> Oklart. Vercel Inc (vercel.com) verkar vara något webapp-företag (Next.js)
}
