// phishers.sieve
// This sieve runs after domains.sieve
// It's aimed at catching certs that have a phished domain in the name, excluding certs
// within the actual domain.

// https://regex101.com/ is a good place to test out regexes



if :notexists source.fqdn {
   drop // Abort processing if we cannot match against it.
}


// Rule for dropping internal matches.
// That is drop <domain.tld>.*.<domain.tld>
// login.chalmers.se.test.chalmers.se would be dropped
// login.gu.se.test.chalmers.se will not be dropped
if source.fqdn =~ '^(?:.*\.)*((arkdes|bornet|bth|chalmers|csbnet|dnlab|du|efs|ehs|esss|fhs|gih|gsix|gu|hb|hh|hhs|hig|his|hkr|hv|irf|ju|junet|kau|kb|ki|kkh|kks|kmh|konstfack|konstnarsnamnden|kth|kth|kulturradet|kva|lansstyrelsen|liu|lnu|ltu|lu|maritima|mau|mdfnet|mdh|mdh|miun|mittag-leffler|modernamuseet|musikverket|nationalmuseum|nordiskamuseet|nrm|oru|raa|riksarkivet|riksdagen|riksutstallningar|rj|rkh|sfhm|sh|shm|sics|skansen|sll|slu|smhi|sophiahemmet|sp|studentnatet|stupi|su|su|sunet|svenskaakademien|tekniskamuseet|tillvaxtverket|uhr|uka|umu|uniarts|unimaster|ur|uu|val|varldskulturmuseerna|vinnova|vr)\.se|(ndgf|nordgen|sipri)\.org|nordu\.net|johannelund\.nu)\..*\1$' {
   drop // drop internal domains
}

// This should match any case where <domain.tld> is part of the fqdn, but not when its the actual domain.
if source.fqdn =~ '^(.*\.)*((arkdes|bornet|bth|chalmers|csbnet|dnlab|du|efs|ehs|esss|fhs|gih|gsix|gu|hb|hh|hhs|hig|his|hkr|hv|irf|ju|junet|kau|kb|ki|kkh|kks|kmh|konstfack|konstnarsnamnden|kth|kth|kulturradet|kva|lansstyrelsen|liu|lnu|ltu|lu|maritima|mau|mdfnet|mdh|mdh|miun|mittag-leffler|modernamuseet|musikverket|nationalmuseum|nordiskamuseet|nrm|oru|raa|riksarkivet|riksdagen|riksutstallningar|rj|rkh|sfhm|sh|shm|sics|skansen|sll|slu|smhi|sophiahemmet|sp|studentnatet|stupi|su|su|sunet|svenskaakademien|tekniskamuseet|tillvaxtverket|uhr|uka|umu|uniarts|unimaster|ur|uu|val|varldskulturmuseerna|vinnova|vr)\.se|(ndgf|nordgen|sipri)\.org|nordu\.net|johannelund\.nu)\..+$' {
//   add source.abuse_contact = 'cert@cert.sunet.se,fors@cert.sunet.se'
   add source.abuse_contact = 'cert@cert.sunet.se'
   add comment = 'Probable phishing domain cert registered'
} else {
   drop
}

// Drop stuff used by cloud security
// https://docs.microsoft.com/en-us/defender-cloud-apps/troubleshooting-proxy-url
// *.admin-mcas.ms
// *.admin-mcas-df.ms
// *.admin-mcas-gov.us
// *.admin-rs-mcas.ms
// *.admin-rs2-mcas.ms
// *.cas.ms
// *.mcas.ms
// *.mcas-df.ms
// *.mcas-gov.us
// *.rs-mcas.ms
// *.rs2-mcas.ms

// regex only on whole name before .ms, .ms is Montserrat TLD and not Microsoft TLD and anyone(?) could register for instance foo-mcas.ms

if source.fqdn =~ '.*\.(?:admin-mcas|admin-mcas-df|admin-mcas-gov|admin-rs-mcas|admin-rs2-mcas|cas|mcas|mcas-df|mcas-gov|rs-mcas|rs2-mcas)\.ms$' {
   drop // Microsoft related
}

// Drop known "good stuff"
if source.fqdn =~ '(fd\.sunet\.se|speedtest\.nordu\.net)\.prod\.hosts\.ooklaserver\.net' {
   // Sunet/Nordunet speedtest server
   drop
} elif source.fqdn :contains 'fhs.se.gov.br' {
   drop // se.gov.br är delstaten Sergipe i brasilien. fhs.se.gov.br verkar ha varit Fundação Hospitalar de Saúde
} elif source.fqdn =~ 'synot\.io$' {
   drop // Synotio AB, www.synotio.se. Svenskt webbhotell
} elif source.fqdn =~ 'hemsida\.eu$' {
   drop // hemsida.eu är Oderland webhotell. Används innan domän pekats om till Oderland
}

// Keep everything that has a source.abuse_contact
if :exists source.abuse_contact {
   keep
}
